@@ -52,8 +52,9 @@ setMethod("plot3D", signature(x='RasterLayer'),
                       }
                       color <- level.colors(Zcol, at=at, col.regions=col)
                   }
+                  ## Open a device only if there is none active
+                  if (rgl::rgl.cur() == 0) rgl::open3d()
                   
-                  rgl::open3d()
                   if (background==min(Zcol)) {
                       trans <- Zcol
                       trans[] <- 1.0
